package fragment;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import com.akamai.captioning.CaptionComponent;
import com.akamai.captioning.CaptioningWrapper;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class EIAFragment extends android.support.v4.app.Fragment implements View.OnTouchListener, IPlayerEventsListener {

    private final static String TAG = "AMP-CC-CEA608";
    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/worldnow/608/master.m3u8";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar mProgressBar;

    private Boolean mWasPlaying = false;
    private MediaResource resource;
    private int mCurrentPosition = 0;

    private CaptionComponent mCaptionComponent; // Captioning plugin
    private CaptioningWrapper mCaptionWrapper;  // The wrapper is used only for CEA-608

     public static EIAFragment newInstance() {
        EIAFragment fragment = new EIAFragment();
        return fragment;
    }

    public EIAFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        mCaptionComponent = (CaptionComponent) rootView.findViewById(R.id.captionView);

        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                resource = mediaResource;

                mVideoView = mVideoContainer.getVideoPlayer();
                mVideoView.setProgressBarControl(mProgressBar);
                mVideoView.setLicense(MainActivity.LICENSE);
                mVideoView.setFullScreen(true);
                mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                mVideoView.setLogEnabled(true);

                //Generate captions after configure the AMP player
                createCaptions();

                mVideoView.addEventsListener(EIAFragment.this);
                mVideoView.setKeepScreenOn(true);
                mVideoView.setOnTouchListener(EIAFragment.this);

                mVideoView.play(resource);
            }

            @Override
            public void onResourceError() {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);

        return rootView;
    }

    /**
     * Caption configuration
     */
    private void createCaptions(){
        // ********************** Captions **********************
        //CaptioningWrapper for CEA-608!
        mCaptionWrapper = new CaptioningWrapper(mCaptionComponent);
        mCaptionWrapper.setVideoPlayerView(mVideoView);

        //Sets captions to video view
        mCaptionComponent.setVideoPlayerView(mVideoView);

        mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_NORMAL_STYLE); // --> no edge
        //mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_OUTLINE_STYLE);  // --> uniform
        //mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_EMBOSS_STYLE);  // raised
        //mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_BEVEL_STYLE); //  --> depressed
        //mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTIONS_TEXT_DROP_SHADOW_STYLE); //--> drop


        mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_DROP_SHADOW_STYLE);
        //mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_RIGHT);
        //mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_BOTTOM);
        //mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_LEFT);
        //mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_RIGHT);

        mCaptionComponent.setTextSize(20);
        mCaptionComponent.setTextBackgroundColor(Color.RED);
        mCaptionComponent.setTextColor(Color.WHITE);
        mCaptionComponent.setTextWindowColor(Color.CYAN);
        mCaptionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_PAINT_ON);
        //mCaptionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_ROLL_UP);

        // Typeface tf = Typeface.createFromAsset(this.getAssets(), "fonts/Arial Black.ttf");
        // mCaptionComponent.setTypeface(tf);
    }

    @Override
    public void onResume() {
        Log.d(TAG, "OnResume");
        if (mWasPlaying && mVideoView != null) {
            mVideoView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d(TAG, "OnPause");
        if(mVideoView != null){
            if (mVideoView.isPlaying() || mVideoView.isPaused()) {
                mCurrentPosition = mVideoView.getTimePosition();
                mWasPlaying = true;
            }
            mVideoView.stop();
        }
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d(TAG, "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d(TAG, "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }
}

