package com.akamai.ampdemo;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class MainActivity extends Activity
        implements DialogInterface.OnCancelListener, IPlayerEventsListener, VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String TAG = "AMPv6";
    private final static String LICENSE = "vcgcJ_EWfa08ixnfP3_tdfKfhUwXd1j10Rb8jsM81xZOUEKW3o1HMC6vC0hSv5lod8ebk_evgilQRYBzb_zFKg==";
    private final static String VIDEO_URL = "http://sblancovodmdev-f.akamaihd.net/i/temp/bbb.mp4/master.m3u8";

    private VideoPlayerContainer mVideoPlayerContainer;
    private VideoPlayerView mVideoPlayerView;
    private ProgressBar mProgressBar;

    private MediaResource resource;

    private boolean mWasPlaying = false;
    private int mCurrentPosition = 0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.addVideoPlayerContainerCallback(this);
        mVideoPlayerContainer.prepareResource(VIDEO_URL);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        resource = mediaResource;

        mVideoPlayerContainer.setDefaultMode(VideoPlayerContainer.MODE_AUTOMATIC);

        mVideoPlayerView = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayerView.setProgressBarControl(mProgressBar);
        mVideoPlayerView.setLicense(LICENSE);
        mVideoPlayerView.setFullScreen(true);
        mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
        mVideoPlayerView.setLogEnabled(true);

        mVideoPlayerView.play(resource, mCurrentPosition);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError() {
        Log.e(TAG, "onResourceError()");
    }

    @Override
    protected void onResume() {
        Log.d(TAG, "onResume");

        if (mWasPlaying) {
            mVideoPlayerView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(TAG, "onPause");

        boolean shouldStop = (mVideoPlayerView != null) && (mVideoPlayerView.isPlaying() || mVideoPlayerView.isPaused());
        if (shouldStop) {
            mCurrentPosition = mVideoPlayerView.getTimePosition();
            mWasPlaying = true;
            mVideoPlayerView.stop();
        }

        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "onDestroy");

        mVideoPlayerView.stop();
        mVideoPlayerView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog)
    {
        finish();
    }

}
